@@ -363,7 +363,7 @@ class RemotesDatabase(object):
 
         # Cope with Unknown vendors:
         # We store 'Unknown' (not translated) in the configuration file in backend.WriteRemoteConfiguration() if vendor is None:
-        vendor_name = vendor;
+        vendor_name = vendor
         if(vendor_name == 'Unknown'):
           vendor_name = None
 
@@ -867,7 +867,13 @@ class KeyListener(gobject.GObject):
 
         if condition & gobject.IO_IN:
             logging.info('reading from lirc socket %d...', fd)
-            packet = self.__socket and self.__socket.recv(128)
+
+            try:
+              # TODO: What is this 128? No magic numbers in code, please.
+              packet = self.__socket and self.__socket.recv(128)
+            except SocketError, ex:
+              logging.error('__on_io_event(): socket.recv() threw exception reading from lirc socket: %s', ex.message)
+              packet = ''
 
             logging.info('...%d bytes received.', len(packet))
             self.__buffer += packet
@@ -997,7 +1003,7 @@ class HardwareConfParser(object):
         self.__values = dict()
 
         for line in open(filename, 'r'):
-            tokens = [t.strip() for t in line.split('=', 2)]
+            tokens = [t.strip() for t in line.split('=', 1)]
 
             if len(tokens) < 2:
                 continue
@@ -1005,6 +1011,7 @@ class HardwareConfParser(object):
             key, value = tokens
 
             value = value.strip('"') # Remove quotes
+            value = ''.join(value.split('\\')) # Remove escaping
             self.__values[key] = value
 
     def __getitem__(self, key):
@@ -1032,27 +1039,21 @@ class HardwareConfParser(object):
         except KeyError:
             return default
 
-def has_include_keyword():
-    '''Checks if include statements are supported in lircd.conf.'''
-
-    return (config.LSB_RELEASE.check(name='Ubuntu', codename='hardy') or
-            config.LSB_RELEASE.check(name='Ubuntu', release='8.04'))
-
 def find_remote_config():
     '''Finds the location our customized lircd.conf file.'''
 
-    if has_include_keyword():
-        return config.LIRC_REMOTE_CONF, True
-
-    return config.LIRC_DAEMON_CONF, False
+    return config.LIRC_REMOTE_CONF
 
 def check_hardware_settings(selected_remote):
     '''Check if the hardware settings are sane.'''
 
-    remote_config, can_include = find_remote_config()
+    remote_config = find_remote_config()
 
-    if can_include and not re.search(
-        r'^\s*include\s+%s\s*$' % re.escape(config.LIRC_REMOTE_CONF),
+    if not os.path.exists(remote_config):
+        return True
+
+    if not re.search(
+        r'^\s*include\s+<%s>\s*$' % re.escape(config.LIRC_REMOTE_CONF),
         open(config.LIRC_DAEMON_CONF).read(), re.MULTILINE):
         return False
 
@@ -1064,7 +1065,7 @@ def check_hardware_settings(selected_remote):
             return False
 
         if selected_remote is None:
-            return False;
+            return False
 
         if (remote.vendor == selected_remote.vendor and
             remote.product == selected_remote.product):
